@@ -11,11 +11,13 @@
 
 package Devel::Ladybug;
 
-our $VERSION = '0.399_003';
+our $VERSION = '0.412_01';
 
 use strict;
 use diagnostics;
 
+use 5.008_008; # Perl 5.8.8+
+
 #
 # Abstract classes
 #
@@ -79,7 +81,7 @@ __END__
 
 =head1 NAME
 
-Devel::Ladybug - Compact schema prototyping (formerly "OP")
+Devel::Ladybug - Data modeling framework
 
 =head1 SYNOPSIS
 
@@ -95,73 +97,40 @@ examples.
 
 =head1 DESCRIPTION
 
-Devel::Ladybug is a Perl 5 framework for prototyping schema-backed
-object classes.
+Devel::Ladybug is a framework for creating and working with data
+models.
 
-Using Devel::Ladybug's C<create()> function, the developer asserts
-rules for object classes. Devel::Ladybug's purpose is to automatically
-derive a database schema, handle object-relational mapping, and provide
-input validation for classes created in this manner.
+Using the C<create()> function, developers may assert rules for
+classes. Devel::Ladybug creates a permanent backing store for these
+classes, and can also handle object-relational mapping and input
+validation.
 
-Devel::Ladybug works with MySQL/InnoDB, PostgreSQL, SQLite, and YAML
-flatfile. If the backing store type for a class is not specified,
-Devel::Ladybug will try to automatically determine an appropriate type
-for the local system. If memcached is available, Devel::Ladybug will
-use it in conjunction with the permanent backing store.
+Supported storage types are YAML or JSON flatfile, MySQL (InnoDB
+engine), PostgreSQL, and SQLite. Memcached, DBIx::TextIndex, and
+RCS may be used in conjunction with the permanent backing store.
 
 =head1 VERSION
 
-This documentation is for version B<0.399_003> of Devel::Ladybug.
-
-=head1 EXPORT TAGS
-
-All exports are optional. Specify a tag or symbol by name to import it
-into your caller's namespace.
-
-  use Devel::Ladybug qw| :all |;
-
-=over 4
-
-=item * :all
-
-This imports each of the symbols listed below.
-
-=item * :create
-
-This imports the C<create> and C<subtype> class prototyping functions;
-see L<Devel::Ladybug::Class>, L<Devel::Ladybug::Subtype>, and examples
-in this document.
-
-=item * :bool
-
-This imports C<true> and C<false> boolean constants.
-
-=item * :yield
-
-This imports the C<yield>, C<emit>, and C<break> functions for array
-collectors; see L<Devel::Ladybug::Array>.
-
-=back
+This documentation is for version B<0.412_01> of Devel::Ladybug.
 
 =head1 FRAMEWORK ASSUMPTIONS
 
-When using Devel::Ladybug, as with any framework, a number of things
-"just happen" by design. Trying to go against the flow of any of these
-base assumptions is not recommended.
+As with any framework, a number of things "just happen" by design.
+Trying to go against the flow of these base assumptions is not
+recommended.
 
 =head2 Configuration
 
 See CONFIGURATION AND ENVIRONMENT in this document.
 
-=head2 Classes Make Tables
+=head2 Table Creation
 
-Devel::Ladybug derives database schemas from the assertions contained
-in object classes, and creates the tables that it needs.
+Database schemas are derived from the assertions contained
+in object classes. Devel::Ladybug creates any needed tables.
 
 =head2 Default Base Attributes
 
-Database-backed Devel::Ladybug objects B<always> have "id", "name",
-"ctime", and "mtime".
+Persistent objects B<always> have "id", "name", "ctime", and "mtime".
 
 =over 4
 
@@ -211,13 +180,11 @@ Devel::Ladybug may use a different name in a future version.
 
 =head2 C<undef> Requires Assertion
 
-Undefined values in objects translate to NULL in the database, and
-Devel::Ladybug does not permit this to happen by default.
-
-Instance variables may not be undef, (and the corresponding table
-column may not be NULL), unless the instance variable was explicitly
-asserted as B<optional> in the class prototype. To do so, provide
-"optional" as an assertion argument, as in the following example:
+Saved instance variables may not be undef (and the corresponding
+table column may not contain NULL) unless the instance variable was
+explicitly asserted as B<optional> in the class prototype. To do
+so, provide "optional" as an assertion argument, as in the following
+example:
 
   create "YourApp::Example" => {
     ### Do not permit NULL:
@@ -237,13 +204,15 @@ asserted as B<optional> in the class prototype. To do so, provide
 
 Devel::Ladybug's core packages live under the Devel::Ladybug::
 namespace. Your classes should live in their own top-level namespace,
-e.g. "YourApp::". This will translate (in lower case) to the name of
-the app's database. The database name may be overridden by implementing
-class method C<databaseName>.
+e.g. "YourApp::YourClass".
+
+The top level namespace (eg "YourApp") translates, in lower case,
+to the name of the app's database. The database name may be overridden
+by implementing class method C<databaseName>.
 
 Namespace elements beyond the top-level translate to lower case table
 names. In cases of nested namespaces, Perl's "::" delineator is swapped
-out for an underscore (_). The table name may be overriden by
+out for an underscore (_). The table name may be overridden by
 implementing class method C<tableName>.
 
   create "YourApp::Example::Foo" => {
@@ -334,7 +303,7 @@ prototype object for its argument.
 =head2 IN METHODS
 
 Constructors and setter methods accept both native Perl 5 data types
-and their Devel::Ladybug object class equivalents. The setters will
+and their Devel::Ladybug object class equivalents. The setters 
 automatically handle any necessary conversion, or throw an exception if
 the received arg doesn't quack like a duck.
 
@@ -351,7 +320,7 @@ To wit, native types are OK for constructors:
   say $example->someString->class;
   # "Devel::Ladybug::Str"
 
-  say $example->someString->size;
+  say $example->someString->length;
   # "3"
 
   say $example->someString;
@@ -434,6 +403,8 @@ asserted as inline attributes.
 
 =item * L<Devel::Ladybug::Class::Dumper> - Introspection mix-in
 
+=item * L<Devel::Ladybug::Node> - Abstract stored object class
+
 =item * L<Devel::Ladybug::Object> - Abstract object class
 
 =item * L<Devel::Ladybug::Persistence> - Storage and retrieval mix-in
@@ -446,14 +417,14 @@ asserted as inline attributes.
 
 =item * L<Devel::Ladybug::Persistence::SQLite> - SQLite overrides
 
-=item * L<Devel::Ladybug::Node> - Abstract stored object class
-
-=item * L<Devel::Ladybug::Type> - Instance variable typing
+=item * L<Devel::Ladybug::Stream> - Buffered iterator for table rows
 
 =item * L<Devel::Ladybug::Scalar> - Base class for scalar values
 
 =item * L<Devel::Ladybug::Subtype> - Instance variable subtyping
 
+=item * L<Devel::Ladybug::Type> - Instance variable typing
+
 =back
 
 =head1 HELPER MODULES
@@ -470,7 +441,7 @@ asserted as inline attributes.
 
 =over 4
 
-=item * C<ladybug-conf> - Generate an .ladybugrc on the local machine
+=item * C<ladybug-conf> - Generate a .ladybugrc on the local machine
 
 =item * C<ladybug-edit> - Edit Devel::Ladybug objects using VIM and YAML
 
@@ -478,6 +449,34 @@ asserted as inline attributes.
 
 =back
 
+=head1 EXPORT TAGS
+
+All exports are optional. Specify a tag or symbol by name to import it
+into your caller's namespace.
+
+  use Devel::Ladybug qw| :all |;
+
+=over 4
+
+=item * :all
+
+This imports each of the symbols listed below.
+
+=item * :create
+
+This imports the C<create> and C<subtype> class prototyping functions.
+
+=item * :bool
+
+This imports C<true> and C<false> boolean constants.
+
+=item * :yield
+
+This imports the C<yield>, C<emit>, and C<break> functions for array
+collectors; see L<Devel::Ladybug::Array>.
+
+=back
+
 =head1 CONFIGURATION AND ENVIRONMENT
 
 =head2 Devel::Ladybug and your DBA
@@ -495,8 +494,8 @@ directory.
 
 To generate a first-time config for the local machine, copy the
 .ladybugrc (included with this distribution as C<ladybugrc-dist>) to
-the proper location, or run C<opconf> (also included with this
-distribution) as the user who will be running Devel::Ladybug.
+the proper location, or run C<ladybug-conf> (also included with this
+distribution) as the user running Devel::Ladybug.
 
 See L<Devel::Ladybug::Constants> for information regarding customizing
 and extending the local rc file.
@@ -516,7 +515,7 @@ For example, in a file C<startup.pl>:
     #
     # Directory with the .ladybugrc:
     #
-    $ENV{LADYBUG_HOME} = '/home/user/dave';
+    $ENV{LADYBUG_HOME} = '/your/ladybug/home';
   }
 
   use YourApp::Component;
@@ -524,12 +523,81 @@ For example, in a file C<startup.pl>:
 
   1;
 
-And in your C<httpd.conf>:
+The startup script should be specified in httpd.conf. Additionally,
+you may need to include a B<PerlSetEnv> directive, for example:
 
   PerlRequire /path/to/your/startup.pl
 
+  <LocationMatch "/.*\.html$">
+    SetHandler perl-script
+
+    PerlHandler HTML::Mason::ApacheHandler
+    PerlSetEnv LADYBUG_HOME /your/ladybug/home
+  </LocationMatch>
+
+=head1 INSTALLATION
+
+Ease of installation is one of Devel::Ladybug's goals. The only
+build requirements are a compiler (C<gcc> or equivalent is needed
+by CPAN to build a few dependencies), and a working Perl 5 (5.8.8
+or greater). Devel::Ladybug's prerequisite Perl packages are handled
+by CPAN, and generally install with no fuss. These are listed in
+Makefile.PL.
+
+=head2 FROM CPAN (RECOMMENDED)
+
+The recommended way to install Devel::Ladybug is via CPAN:
+
+  perl -MCPAN -e 'install Devel::Ladybug'
+
+Answer "yes" when prompted to install dependencies. You must (of
+course) have permission on your local system to do so, which means
+you either have superuser access, or your user owns the Perl install.
+
+Devel::Ladybug does not depend on any particular DBI driver-- the
+package of your choice needs to be installed separately in order
+to be usable by Devel::Ladybug as a backing store type. Currently
+supported drivers are: L<DBD::mysql>, L<DBD::Pg>, and L<DBD::SQLite>.
+
+=head2 FROM SOURCE
+
+Assuming dependencies have been installed, installation may also
+be done manually:
+
+  cd Devel-Ladybug-xxxx
+  perl Makefile.PL # Warns if system is missing prereqs
+  make test
+  make install
+
+=head2 INSTALL PROBLEMS?
+
+The most common installation problem is due to a compiler not being
+present on the local machine. After installing gcc, you may need
+to purge the contents of the CPAN build directory to avoid cached
+failed build results (e.g. ~root/.cpan/build/*), and re-run the
+installation.
+
+Refer to recent CPAN Testers results to see if Devel::Ladybug
+"should" work with your particular software stack. Installation
+problems may be reported to the author via email (please include
+the output from C<make test>)
+
+  http://static.cpantesters.org/distro/D/Devel-Ladybug.html
+
+=head2 BUGS AND LIMITATIONS
+
+This code is now in maintenance mode, and is unlikely to receive
+significant new features. There are several similar frameworks on
+CPAN which are more active, you may want to check those out first.
+
+Tests show that Ladybug objects have precision problems, if Perl was
+built with long double support. This is a compilation issue with
+one of Ladybug's dependencies, and has not been isolated.
+
 =head1 SEE ALSO
 
+L<Devel::Ladybug::TLDR>
+
 L<Devel::Ladybug::Class>
 
 Devel::Ladybug is on GitHub: http://github.com/aayars/ladybug
@@ -542,9 +610,10 @@ Support is available from the author via email.
 
   Alex Ayars <pause@nodekit.org>
 
-=head1 COPYRIGHT
+=head1 LICENSE AND COPYRIGHT
 
   Copyright (c) 2009 TiVo Inc.
+  Copyright (c) 2010 Alex Ayars
  
   All rights reserved. This program and the accompanying materials
   are made available under the terms of the Common Public License v1.0
